@@ -529,7 +529,9 @@ def prete_livre(request):
 @i18n
 def prets_go(request):
     """
-    Force le prêt de livres à quelq'un
+    Force le prêt de livres à quelq'un ; par effet de bord, ça efface
+    des enregistrements d'instances de Livre_a_lire pour chaque livre prêté
+    de la catégorie "Poche"
     Paramètres postés : "nomprenom", "liste_codes", "etats"
     """
     nomprenom = request.POST.get("nomprenom", "")
@@ -538,6 +540,11 @@ def prets_go(request):
     eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
     date = datetime.now().strftime("%Y-%m-%d")
     manuels = [ Inventaire.objects.get(id = code) for code in liste_codes ]
+    poches = [m.materiel for m in manuels if m.materiel.is_poche]
+    for p in poches:
+        a_lire = Livre_a_lire.objects.filter(eleve = eleve, livre = p)
+        if a_lire:
+            a_lire[0].delete()
     for etat, manuel in zip(etats, manuels):
         if manuel.actuellement_a() is not None:
             continue # on ne prête pas un manuel actuellement prêté ni perdu
@@ -755,8 +762,24 @@ def correspondance_nom(request):
         
         classes_a_chercher = [c.libelle for c in Classes.classes_importantes()]\
             + [NOCLASS]
-        correspond = [e.NomPrenomEleve for e in \
-                       eleves if e.Lib_Structure in classes_a_chercher ]
+        correspond = sorted([e.NomPrenomEleve for e in \
+                       eleves if e.Lib_Structure in classes_a_chercher ])
+    else:
+        correspond = []
+    return JsonResponse(correspond, safe=False)
+
+@ensure_csrf_cookie
+@i18n
+def correspondance_nom_caution(request):
+    """
+    Recherche des noms/prénoms correspondant au début donné par le
+    paramètre term
+    """
+    if request.headers.get('x-requested-with') == 'XMLHttpRequest':
+        query = request.POST.get("term", "")
+        query = sans_accent(query).lower()
+        cautions = Caution.objects.filter(sans_accent__contains=query)
+        correspond = sorted(list(set([c.nomprenom for c in  cautions])))
     else:
         correspond = []
     return JsonResponse(correspond, safe=False)
@@ -1429,22 +1452,27 @@ def effaceEleve(request):
 def sortieParSiecle(request):
     """
     Effacement des élèves qui sont dans la base et ne sont plus dans
-    l'import SIÈCLE. Les élèves qui ont encore quelque chose à rendre
-    ne sont pas effacés.
+    l'import SIÈCLE. Les élèves qui ont encore quelque chose à rendre,
+    ou dont la caution n'a pas été marquée comme rendue, ne sont pas effacés.
     """
     liste_eleves = Eleves_de_siecle.objects.all()
     liste_sans_prets = Eleves.sans_prets_en_cours()
+    liste_sans_prets_ni_caution = [
+        e for e in liste_sans_prets if e.caution_rendue
+    ]
     liste_sortants = [e for e in Eleves.objects.all() if not e.homonymes(liste_eleves)]
     pas_de_classe = Classes.objects.get(libelle = NOCLASS)
     for e in liste_sortants :
         e.classe = pas_de_classe
         e.Lib_Structure = NOCLASS
         e.save()
-    liste_sortants_sans_prets = [
-                e for e in liste_sans_prets if not e.homonymes(liste_eleves)]
-    nb = len(liste_sortants_sans_prets)
+    liste_sortants_sans_prets_ni_caution = [
+        e for e in liste_sans_prets_ni_caution
+        if not e.homonymes(liste_eleves)
+    ]
+    nb = len(liste_sortants_sans_prets_ni_caution)
     classes_touchees = set() # ensemble des classes modifiées
-    for e in liste_sortants_sans_prets:
+    for e in liste_sortants_sans_prets_ni_caution:
         classes_touchees.add(e.classe)
         e.delete()
     # on remet à jour l'effectif des classes touchées par l'inscription
@@ -1462,8 +1490,6 @@ def sortieParSiecle(request):
         "title": _("Nettoyage terminé"),
     })
 
-@ensure_csrf_cookie
-@i18n
 def sortieParSiecle_msg(request):
     """
     Gère le message temporaire de la fonction JS sortieParSiecle
@@ -1473,6 +1499,7 @@ def sortieParSiecle_msg(request):
         "alt_img": _("Attendre ..."),
         "title": _("Effacement en cours"),
     }
+    return JsonResponse(data)
 
 @ensure_csrf_cookie
 @i18n
@@ -1485,28 +1512,38 @@ def importeSiecle(request):
     message=_("fichier SIÈCLE importé")
     csvfile = request.POST.get("csv")
     format_str = StringIO(csvfile)
+    # première passe : on repère tous les libellés des classes
+    # puis on crée les classes manquantes
+    format_str.seek(0)
+    reader = csv.DictReader(format_str, delimiter=",")
+    nouvelles_classes = set((d['Code Structure'] for d in reader))
+    ancienne_classes = set([c.libelle for c in Classes.objects.all()])
+    classes_a_creer = nouvelles_classes - ancienne_classes
+    classes_a_supprimer = ancienne_classes - nouvelles_classes
+    for c in classes_a_creer:
+        laclasse = Classes(code = c, libelle = c, compte = 0)
+        laclasse.save()
+    for c in classes_a_supprimer:
+        print("IMPORTANT : il faudrait arbitrer la suppression des classes de l'ensemble", classes_a_supprimer)
+    # deuxième passe on se préoccupe des élèves
     format_str.seek(0)
     reader = csv.DictReader(format_str, delimiter=",")
     liste_eleves = list(Eleves_de_siecle.from_csv(reader))
     if liste_eleves:
-        # efface ment de la table temporaire avant repeuplement
+        # effacement de la table temporaire avant repeuplement
         Eleves_de_siecle.objects.all().delete()
-    nouvelles_classes = set()
     for e in liste_eleves:
-        nouvelles_classes.add(e.Lib_Structure)
         e.save() # on peuple la table gestion_eleves_de_siecle
-    ancienne_classes = set([c.libelle for c in Classes.objects.all()])
-    classes_a_creer = [c for c in nouvelles_classes if c not in ancienne_classes]
-    for c in classes_a_creer:
-        laclasse = Classes(code = c, libelle = c, compte =0)
-        laclasse.save()
     a_afficher = [str(e) for e in liste_eleves]
     return JsonResponse({
         "ok": ok,
         "message": message,
         "a_afficher": sorted(a_afficher),
         "title": _("Fichier SIÈCLE traité"),
+        "classes_a_supprimer": list(classes_a_supprimer),
     })
+### !!! travail à faire : permettre une interaction directe pour supprimer
+### !! (ou pas) des classes absentes de l'import siècle.
 
 @ensure_csrf_cookie
 @i18n
@@ -1544,6 +1581,7 @@ def nouveaux_sortants_modifier(request):
     a_modifier = [str(e) for e in liste_modifier]
     a_modifier_vraiment = [str(e) for e in liste_modifier_vraiment]
     donnees_siecle = {}
+    quasi_h = {}
     for n in qh:
         e = Eleves_de_siecle.objects.filter(sans_accent = n)[0]
         donnees_siecle[n] = {
@@ -1553,6 +1591,10 @@ def nouveaux_sortants_modifier(request):
             "nomprenom": e.Nom_de_famille+ " " + e.Prenom,
             "autre": qh[n],
         }
+        candidats = Eleves.objects.filter(
+            sans_accent = qh[n])
+        if candidats:
+            quasi_h[n] = candidats[0].doit
     return JsonResponse({
         "ok": True,
         "message": "nouveaux, sortants et à moditer trouvés",
@@ -1561,8 +1603,7 @@ def nouveaux_sortants_modifier(request):
         "a_modifier": sorted(a_modifier),
         "a_modifier_vraiment": sorted(a_modifier_vraiment),
         "liste_doublons_siecle": sorted(liste_doublons_siecle),
-        "quasi_homonymes": {n: Eleves.objects.filter(
-            sans_accent = qh[n])[0].doit for n in qh},
+        "quasi_homonymes": quasi_h,
         "donnees_siecle": donnees_siecle,
     })
 
@@ -1731,7 +1772,7 @@ def nouvelle_caution(request):
     nomprenom = request.POST.get("nomprenom")
     eleve = Eleves.objects.get(NomPrenomEleve  = nomprenom)
     autres_cautions = Caution.objects.filter(
-        nom = eleve.NomPrenomEleve, prenom = eleve.Prenom)
+        nom = eleve.Nom_de_famille, prenom = eleve.Prenom)
     for c in autres_cautions:
         if c.est_valide:
             ok=False
@@ -1944,19 +1985,21 @@ def affiche_caution_eleve(request):
     nomprenom = request.POST.get("nomprenom")
     cautions = []
     eleve = ""
+    ok = False
     try:
-        eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
-        cautions = Caution.objects.filter(
-            nom = eleve.Nom_de_famille, prenom = eleve.Prenom)
+        cautions = Caution.objects.filter(sans_accent = sans_accent(nomprenom).lower())
+        eleveList = Eleves.objects.filter(NomPrenomEleve = nomprenom)
+        ok = True
     except ObjectDoesNotExist:
         pass
     data = {
         "html": render_to_string('gestion/affiche_caution_eleve.html', {
-            "eleve": eleve,
+            "eleve": eleveList[0] if eleveList else None,
+            "nomprenom": nomprenom,
             "cautions": cautions,
 	}),
         "nomprenom": nomprenom,
-        "ok": bool(eleve),
+        "ok": ok,
     }
     return JsonResponse(data)
 
@@ -2115,7 +2158,9 @@ def au_pilon(request):
 
 def livre_html(li, option=None):
     """
-    représentation d'un livre au format html, pour la boutique
+    représentation d'un livre au format html, pour la boutique.
+    Dans le cas particulier des livres de poche, l'abrégé visible sera
+    précisé plus avant.
     @param li une instance de Matériel
     @param option précise la présentation (None par défaut)
     @return une chaîne html sûre
@@ -2125,19 +2170,13 @@ def livre_html(li, option=None):
             "l": li,
     })
 
-    
-@ensure_csrf_cookie
-@i18n
-def mes_livres_en_boutique(request):
+
+def livres_pour_eleve(eleve):
     """
-    Permet de définir les livres du tronc commun et les autres, étant donné
-    un élève. POST fournit le paramètre nomprenom
-    
-    la constante CORRELATION représente un tableau
-    de corrélation entre options de SIÈCLE et abrégés de livres
+    Crée deux listes de livres pour un élève : les livres qu'il devrait
+    prendre et les livres pour sa classe qu'il devrait laisser
+    @param eleve une instance de Eleves
     """
-    nomprenom = request.POST.get("nomprenom")
-    eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
     classe = eleve.Lib_Structure
     categorie = Classes.to_categorie(classe)
     matieres = []
@@ -2168,10 +2207,15 @@ def mes_livres_en_boutique(request):
                 if v > max:
                     max = v
                     abg = k
-            if abg:
+            if abg and abg != "poche":
+                # les livres de poche ne sont pas ajoutés aux livres d'option
+                # à ce stade ; on consultera plutôt la table des livres à lire
                 livres_options += list((Materiel.objects.filter(abrege = abg)))
     livres_tc += [
         livre_html(li) for li in Materiel_regroupe.regroupe(livres_options)]
+    livres_poche= list(
+        (l.livre for l in Livre_a_lire.objects.filter(eleve = eleve)))
+    livres_tc += [livre_html(li) for li in livres_poche]
     # autres livres
     livres_autres = [
         livre_html(li) for li in
@@ -2181,6 +2225,33 @@ def mes_livres_en_boutique(request):
             - set(livres_options)
         )
     ]
+    return livres_tc, livres_autres
+
+@ensure_csrf_cookie
+@i18n
+def mes_livres_en_boutique(request):
+    """
+    Permet de définir les livres du tronc commun et les autres, étant donné
+    un élève. POST fournit le paramètre nomprenom
+    
+    la constante CORRELATION représente un tableau
+    de corrélation entre options de SIÈCLE et abrégés de livres
+    """
+    nomprenom = request.POST.get("nomprenom")
+    eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
+    classe = eleve.Lib_Structure
+    livres_tc, livres_autres = livres_pour_eleve(eleve)
+    matieres = []
+    matieres.append(eleve.Lib_Mat_Enseignee_1)
+    matieres.append(eleve.Lib_Mat_Enseignee_2)
+    matieres.append(eleve.Lib_Mat_Enseignee_3)
+    matieres.append(eleve.Lib_Mat_Enseignee_4)
+    matieres.append(eleve.Lib_Mat_Enseignee_5)
+    matieres.append(eleve.Lib_Mat_Enseignee_6)
+    matieres.append(eleve.Lib_Mat_Enseignee_7)
+    matieres.append(eleve.Lib_Mat_Enseignee_8)
+    matieres.append(eleve.Lib_Mat_Enseignee_9)
+    matieres.append(eleve.Lib_Mat_Enseignee_10)
     data = {
         "classe": classe,
         "matieres": matieres,
@@ -2217,6 +2288,19 @@ def qr_boutique_print_go(request):
     pages = etiquettes.makePDF(etiqs, [])
     return FileResponse(pages, as_attachment=True, filename="qr_boutique.pdf")
 
+def action_courrier_go(request):
+    """
+    Création d'étiquettes pour du courrier
+    le POST contient les paramètres tabous et noms
+    """
+    tabous = json.loads(request.POST.get("tabous","[]"))
+    noms = json.loads(request.POST.get("noms","[]"))
+    eleves = Eleves.objects.filter(NomPrenomEleve__in = noms)
+    etiqs = [etiquettes.EtiquetteAdresse(e) for e in eleves]
+    pages = etiquettes.makePDF(etiqs, tabous)
+    return FileResponse(pages, as_attachment=True, filename="etiquettes_adresse.pdf")
+    
+
 
 @i18n
 def plus_livre_supplement(request):
@@ -2563,3 +2647,61 @@ def makeImmobile_msg(request):
     }
     return JsonResponse(data)
 
+@ensure_csrf_cookie
+@i18n
+def que_prendre(request):
+    """
+    Renvoie du code html pour afficher dans un dialogue la liste des livres
+    que doit prendre un élève
+    Le POST fournit le paramètre nomprenom
+    """
+    nomprenom = request.POST.get("nomprenom")
+    eleve = Eleves.objects.get(NomPrenomEleve = nomprenom)
+    livres_tc, livres_autre = livres_pour_eleve(eleve)
+    data = {
+        "html": render_to_string('gestion/que_prendre.html', {
+            "livres": livres_tc,
+            "eleve": eleve,
+            })
+    }
+    return JsonResponse(data)
+
+def livres_de_classe(request):
+    """
+    Renvoie du code HTML utilisable pour montrer dans un dialogue les
+    livres à préparer pour une classe donnée. Le POST contient le paramètre
+    classe
+    """
+    classe = request.POST.get("classe")
+    categorie = Classes.to_categorie(classe)
+    livres = list(Materiel_regroupe.regroupe(
+        Materiel.objects.filter(categories__contains = categorie)))
+    eleves = Eleves.objects.filter(Lib_Structure = classe)
+    livres_poche= set(
+        (l.livre for e in eleves for l in Livre_a_lire.objects.filter(eleve = e)
+         ))
+    livres += list(livres_poche)
+    data = {
+        "html": render_to_string('gestion/livres_de_classe.html', {
+            "livres": livres,
+            "classe": classe,
+            })
+    }
+    return JsonResponse(data)
+
+@ensure_csrf_cookie
+@i18n
+def livre_retrouve_go(request):
+    """
+    Dé-perd un livre quand on a confirmé l'avoir retrouvé
+    le POST donne le paramètre id
+    """
+    id = request.POST.get("id")
+    l = Inventaire.objects.get(id = id)
+    l.Perdu = False
+    l.save()
+    data = {
+        "OK": True,
+    }
+    return JsonResponse(data)
+
