@@ -59,6 +59,7 @@ if platform.system() != "Windows":
                                    '/usr/share/fonts/truetype/liberation/LiberationSans-BoldItalic.ttf'))
 
 PADDING = 1
+BORDER = False # trace les limites des étiquettes ou pas
 
 def pt2mm(long):
     """
@@ -1028,6 +1029,41 @@ class CartesMembre_verso(EtiquetteBase):
         self.drawSignature()
         return
     
+class EtiquetteAdresse(EtiquetteBase):
+    """
+    Structure de données pour les étiquettes d'adresse concernant un élève :
+    @param e une instance d'Eleves
+    """
+    def __init__(self, e):
+        self.eleve = e
+        return
+
+    def drawNom(self):
+        self.addParagraph(
+            self.eleve.NomPrenomEleve, 2, 25, lineheight=6,
+            maxLines=1, fontSize=10, join=" ")
+        return
+
+    def drawAdresse(self):
+        debut, code = self.eleve.adresse_codepostal()
+        self.addParagraph(
+            debut, 2, 21, lineheight=4,
+            maxLines=5, fontSize=7.5, join=" ")
+        self.addParagraph(
+            code, 2, 8, lineheight=4,
+            maxLines=2, fontSize=10, join=" ")
+        return
+    
+    def make_label(self, label, w, h):
+        """
+        Enchaîne toutes les étapes de création de l'étiquette, pour
+        la bibliothèque pylabels.
+        """
+        self.pylabel, self.w, self.h = label, w, h
+        self.drawNom()
+        self.drawAdresse()
+        return
+
 def makePDF(data, tabou):
     """
     Produit un fichier PDF de planches d'étiquettes
@@ -1038,7 +1074,8 @@ def makePDF(data, tabou):
     @return un pseudo-fichier, ouvert en lecteur, initialisé à son début
     """
     sheet = labels.Sheet(
-        EtiquetteJeanBart.specs, EtiquetteJeanBart.draw_etiquette, border=False)
+        EtiquetteJeanBart.specs, EtiquetteJeanBart.draw_etiquette,
+        border=BORDER)
     sheet.partial_page(1,[(int(pos["row"]), int(pos["col"])) for pos in tabou])
     for etiquette in data:
         sheet.add_label(etiquette)
