@@ -348,7 +348,7 @@ class Classes(models.Model):
         Renvoie une liste, dans l'ordre de passage chronologique
         """
         # Translators: those are begins of class names in order of age in France
-        ordre = json.loads(_('["6", "5", "4", "3", "2", "1", "T"]'))
+        ordre = json.loads(_('["6", "5", "4", "3", "2", "1", "T", "P"]'))
         c = set()
         for i in Classes.classes_importantes():
             c.add(Classes.to_categorie(i.libelle))
@@ -389,7 +389,7 @@ class Classes(models.Model):
         # structure : [(regexp de sélection, regexp d'interdiction)]
         # vérifier que json.loads fonctionnera après traduction aussi !
         # Translators: this is a list of regexps to select/unselect important classes
-        CLASSE_CAUTION_RE = json.loads(_('[["^2D.*", "^2D00.*"], ["^1.*", ""], ["^TMC.*", ""], ["^TRH.*", ""], ["^TG[0-9]", ""], ["^TGF.*", ""]]'))
+        CLASSE_CAUTION_RE = json.loads(_('[["^2D.*", "^2D00.*"], ["^1.*", ""], ["^TMC.*", ""], ["^TRH.*", ""], ["^TG[0-9]", ""], ["^TGF.*", ""], ["^Pro.*", ""]]'))
         Qsums=[]
         for rselect, rnot in  CLASSE_CAUTION_RE:
             if rnot:
@@ -1310,6 +1310,7 @@ class Eleves(Eleves_abstract):
                 ligne = Caution(nom = self.Nom_de_famille,
                                 prenom = self.Prenom,
                                 numero = self.no_caution,
+                                sans_accent = self.sansaccent,
                                 classe = (self.Lib_Structure or ""),
                                 date = datetime.now().date())
                 ligne.save()
@@ -2141,6 +2142,7 @@ class Caution(models.Model):
                 date_ = e.date_inscription_coop
             caution = Caution(
                 numero = e.no_caution, nom = e.Nom_de_famille,
+                sans_accent = e.sans_accent,
                 prenom = e.Prenom, date = date_,
                 classe = e.Lib_Structure,
         )
