@@ -257,4 +257,6 @@ urlpatterns = [
     path('action_courrier', views.action_courrier, name='action_courrier'),
     path('action_courrier_go', ajaxviews.action_courrier_go,
          name='action_courrier_go'),
+    path('essai_svg', views.essai_svg,
+         name='essai_svg'),
 ]
