@@ -10,6 +10,8 @@ from numpy import nan_to_num
 from base64 import b64encode
 from subprocess import Popen, PIPE
 
+from django.utils.translation import gettext as _
+
 def svg_histogram(r, title="", label="", bins = 10):
     """
     Création d'un histogramme au format SVG
@@ -37,11 +39,11 @@ def demo_svg_histogram():
     r = np.random.randn(1000)
     with open ("svg_histogram.svg", "w") as outfile:
         outfile.write(svg_histogram(
-            r, "Voici un histogramme.", 'Nombre de livres prêtés'
+            r, _("Voici un histogramme."), _('Nombre de livres prêtés')
         ))
     return
 
-def svg_actions_datees(dates, name="date de ..."):
+def svg_actions_datees(dates, name=""):
     """
     Création d'un graphique au format SVG, qui présente une frise
     chronologique des nombres d'actions, regroupées par dates
@@ -51,8 +53,7 @@ def svg_actions_datees(dates, name="date de ..."):
     @param name un label expliquant le nature des dates
     @return une chaîne de caractères
     """
-    # gettext_lazy peut être cause de difficultés, on force une évaluation
-    name = str(name)
+    name = str(name) if name else _("date de ...")
     matplotlib.use('agg')
     plt.rcParams['svg.fonttype'] = 'none'
     f = StringIO()
@@ -62,11 +63,11 @@ def svg_actions_datees(dates, name="date de ..."):
     f.seek(0)
     les_dates = pd.read_csv(f, parse_dates=[name])
     s = les_dates.groupby(les_dates[name])[name].count()
-    s = s.resample("1d").apply({"compte": lambda x: sum(nan_to_num(x))})
+    s = s.resample("1d").apply({_("compte"): lambda x: sum(nan_to_num(x))})
     fig,ax1 = plt.subplots()
 
     plt.plot(s.index, s.values)
-    plt.title("nombre d'opérations, selon la " + name)
+    plt.title(_("nombre d'opérations, selon la {d}").format(d = name))
 
     ax1.xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m'))
     plt.xticks(rotation=30)
@@ -80,7 +81,7 @@ def demo_svg_actions_datees():
     with open ("svg_dates_prets.svg", "w") as outfile:
         outfile.write(svg_actions_datees(
             (p.date_pret for p in Prets.objects.all()),
-            "date de prêt"
+            _("date de prêt")
         ))
     return
 
