@@ -1607,3 +1607,14 @@ def action_courrier(request):
         })
 
     
+def essai_svg(request):
+    """
+    page expérimentale pour bricoler des graphes de dépendances
+    """
+    return render_common(
+        request,
+        'gestion/essai_svg.html',
+        _("essai SVG"),
+        {
+            "aide": "",
+        })
