@@ -2,7 +2,7 @@
     gestion.views_download, un module pour SLM
     - rendu des pages imprimables (via un format PDF)
 
-    Copyright (C) 2023 Georges Khaznadar <georgesk@debian.org>
+    Copyright (C) 2023-2024 Georges Khaznadar <georgesk@debian.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,9 @@ from django.template.loader import get_template
 from django.core.management import call_command
 from django.views.decorators.csrf import ensure_csrf_cookie
 from django.db.models import Q
-# from django.utils.safestring import mark_safe
+from django.utils.safestring import mark_safe
 from django.db.models import Max, Min
+from django.utils.translation import gettext_lazy as _
 
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.ttfonts import TTFont
@@ -31,6 +32,8 @@ import platform
 import json
 import traceback
 
+from .decorators import i18n
+
 if platform.system() != "Windows":
     pdfmetrics.registerFont(TTFont('Serif',
                                    '/usr/share/fonts/truetype/liberation/LiberationSerif-Regular.ttf'))
@@ -52,11 +55,13 @@ from datetime import date, datetime
 
 from .models import Eleves, Classes, MIN_NO_CAUTION, Caution, Parametres, \
     Courriers, Prets, DATE111, Materiel, Eleves_de_siecle, TypeMateriel, \
-    Filieres, Series, Disciplines, Niveaux
+    Filieres, Series, Disciplines, Niveaux, NOCLASS, LIMITE_ANNEE_SCOLAIRE
+
 from manuels.settings import BASE_DIR, MEDIA_ROOT
 
 @ensure_csrf_cookie
-def render_pdf(request,template, context, filename="download.pdf"):
+@i18n
+def render_pdf(request,template, context, filename=_("téléchargement.pdf")):
     """
     Rendu sous forme d'un fichier PDF ; template est un modèle au format
     RML que définit Reportlab, context est un dictionnaire pour interpréter
@@ -84,7 +89,7 @@ def render_pdf(request,template, context, filename="download.pdf"):
                     "template": template,
                 })))
     buffer.seek(0)
-    return FileResponse(buffer, as_attachment=True, filename=filename)
+    return FileResponse(buffer, as_attachment=True, filename=str(filename))
 
 def manuel_bidon():
     """
@@ -101,8 +106,8 @@ def manuel_bidon():
         tm = type_materiel[0]
     else:
         tm = TypeMateriel(
-            libelle_long = "Manuel scolaire",
-            libelle_court = "Manu",
+            libelle_long = _("Manuel scolaire"),
+            libelle_court = _("Manu"),
             Tarif_Perdu = ".",
             Tarif_Degradation = ".",
             Choix_Tarif_Degradation = False,
@@ -114,8 +119,8 @@ def manuel_bidon():
         discipline = d[0]
     else:
         discipline = Disciplines(
-            libelle = "LETTRES",
-            abrege = "LET",
+            libelle = _("LETTRES"),
+            abrege = _("LET"),
         )
         discipline.save()
     n = Niveaux.objects.all()
@@ -123,8 +128,8 @@ def manuel_bidon():
         niveau = n[0]
     else:
         niveau = Niveaux(
-            libelle = "Seconde",
-            abrege = "2NDE",
+            libelle = _("Seconde"),
+            abrege = _("2NDE"),
             rang = "E",
         )
         niveau.save()
@@ -133,7 +138,7 @@ def manuel_bidon():
         filiere = f[0]
     else:
         filiere = Filieres(
-            nom = "Générale",
+            nom = _("Générale"),
         )
         filiere.save()
     s = Series.objects.all()
@@ -141,16 +146,16 @@ def manuel_bidon():
         serie = s[0]
     else:
         serie =  Series(
-            libelle_court = "toutes",
-            libelle_long = "Toutes séries de la filière",
+            libelle_court = _("toutes"),
+            libelle_long = _("Toutes séries de la filière"),
         )
         serie.save()
         
     return Materiel(
         type_materiel = tm,     # instance de TypeMateriel
-        titre = "C'est un livre bidon",
-        editeur = "Éditeur",
-        ISBN = "ISBN",
+        titre = _("C'est un livre bidon"),
+        editeur = _("Éditeur"),
+        ISBN = _("ISBN"),
         discipline = discipline, # instance de Disciplines
         niveau = niveau,         # instance de Niveaux
         filiere = filiere,       # instance de Filieres
@@ -166,9 +171,10 @@ def catalogue_print(request):
         request,
         'gestion/catalogue.rml', {
             "manuels": manuels,
-            "date": datetime.now().strftime("%d %m %Y à %H:%M"),
+            # Translators : this is a format for strftime
+            "date": datetime.now().strftime(str(_("%d %m %Y à %H:%M"))),
             "logo": logo,
-        }, filename = "catalogue.pdf")
+        }, filename = _("catalogue.pdf"))
 
 @ensure_csrf_cookie
 def saveDB(request):
@@ -229,7 +235,7 @@ def prets_mkPDF(request):
             "sum": total,
             "params": params,
         },
-        filename="pret_{}.pdf".format(safeIdent(nomprenom))
+        filename=_("pret_{}.pdf").format(safeIdent(nomprenom))
     )
 
 def avenant_mkPDF(request):
@@ -280,7 +286,7 @@ def avenant_mkPDF(request):
             "sum": total,
             "params": params,
         },
-        filename="avenant{}_{}.pdf".format(n,safeIdent(nomprenom))
+        filename=_("avenant{}_{}.pdf").format(n,safeIdent(nomprenom))
     )
 
 def imprime_restitution(request):
@@ -317,7 +323,7 @@ def imprime_restitution(request):
             "nb_non_rendu": len(manuels) - len(rendus),
             "lesprix": lesprix,
         },
-        filename="rendu_{}.pdf".format(safeIdent(nomprenom))
+        filename=_("rendu_{}.pdf").format(safeIdent(nomprenom))
     )
 
 def imprime_memoire(request):
@@ -337,7 +343,7 @@ def imprime_memoire(request):
     )
     lesprix = [m.inventaire.materiel.Prix for m in manuels]
     messages = Courriers.objects.order_by("N").reverse()
-    messages_rendu = messages[0].Retour_Recommandation
+    messages_rendu = messages[0].Memoire
     params, logo = constantes()
     tarifs = [m.tarif for m in manuels]
     rendus = [m for m in manuels if m.isRendu]
@@ -346,7 +352,7 @@ def imprime_memoire(request):
         'gestion/fiche_memoire.rml', {
             "eleve": eleve,
             "manuels": manuels,
-            "messages": messages_rendu.split("\n"),
+            "messages": [mark_safe(l) for l in messages_rendu.split("\n")],
             "date": datetime.now(),
             "logo": logo,
             "params": params,
@@ -354,7 +360,7 @@ def imprime_memoire(request):
             "nb_non_rendu": len(manuels) - len(rendus),
             "lesprix": lesprix,
         },
-        filename="memoire_{}.pdf".format(safeIdent(nomprenom))
+        filename=_("memoire_{}.pdf").format(safeIdent(nomprenom))
     )
 
 def constantes():
@@ -373,17 +379,17 @@ def constantes():
     else:
         # on crée des constantes bidon
         params = Parametres(
-            NomAcademie = "Test",
-            NomEts = "Lycée bidon",
-            CodeRNE = "0590071g",
-            Commune = "Nulle part",
-            Titre_ChefEts = "Proviseur",
-            Civilite_ChefEts = "Mme",
-            NomChefEts = "La proviseure",
-            Civilite_AgentComptable = "M",
-            NomAgentComptable = "L'intendant",
+            NomAcademie = _("Test"),
+            NomEts = _("Lycée bidon"),
+            CodeRNE = _("0590071g"),
+            Commune = _("Nulle part"),
+            Titre_ChefEts = _("Proviseur"),
+            Civilite_ChefEts = _("Mme"),
+            NomChefEts = _("La proviseure"),
+            Civilite_AgentComptable = _("M"),
+            NomAgentComptable = _("L'intendant"),
             AnneeScolaire = datetime.now().strftime("%Y"),
-            Adresse = "1 rue du lycée",
+            Adresse = _("1 rue du lycée"),
             CodePostal = "00000",
             Telephone = "010203040506",
         )
@@ -408,21 +414,50 @@ def cahier_cautions(request):
         # on crée une liste avec une seule instance bidon de Caution
         bidon = Caution(
             numero = MIN_NO_CAUTION,
-            nom = "Il n'y a pas encore d'élèves",
-            prenom = "Il faudrait nourrir la base de données !",
+            nom = _("Il n'y a pas encore d'élèves"),
+            prenom = _("Il faudrait nourrir la base de données !"),
             date = datetime.now(),
-            classe = "2d00",
-            commentaire="Il faudrait entrer quelques élèves dans la base !",
+            # Translators : this is a name of a French class at the
+            # begin of the high school (students are aged 15)
+            classe = _("2d00"),
+            commentaire=_("Il faudrait entrer quelques élèves dans la base !"),
         )
         cautions = [bidon]
+    premiere_date = min((c.date for c in cautions))
+    derniere_date = max((c.date for c in cautions))
+    if premiere_date.month >= 7:
+        year = premiere_date.year
+    else:
+        year = premiere_date.year - 1
+    debut_cautions = date(year, 7, 1)
+    if derniere_date.month < 7:
+        year = derniere_date.year
+    else:
+        year = derniere_date.year + 1
+    fin_cautions = date(year, 7, 1)
+    cautions_par_annee = {}
+    annee_cautions = debut_cautions
+    year = annee_cautions.year                   # ex: 2023
+    while year < fin_cautions.year:
+        s_year = f"{year}/{int(str(year)[2:]) + 1}"  # ex: "2023/24"
+        next_year = year + 1
+        debut = date(year, 7, 1)
+        fin = date(next_year, 7, 1)
+        cautions_par_annee[year] = {
+            "school_year": s_year,
+            "cautions": Caution.objects.filter(
+                numero__gt = MIN_NO_CAUTION, date__gte = debut, date__lt = fin)
+        }
+        year = next_year
     return render_pdf(
         request,
         'gestion/cahier_cautions.rml', {
-            "cautions": cautions,
+            "cautions_par_annee": cautions_par_annee,
+            "NOCLASS": NOCLASS,
             "colWidths": "1.8cm,5.6cm,3.4cm,2.5cm,4.7cm",
             "vpadding": "0.964mm", # ajustement pour des lignes de 8 mm
         },
-        filename="cahier_cautions.pdf",
+        filename=_("cahier_cautions.pdf"),
     )
 
 @ensure_csrf_cookie
@@ -434,7 +469,7 @@ def listes_eleves(request):
     Nom_de_famille, Prenom et laisse de la place pour ajouter des commentaires
     """
     classes = [c for c in Classes.classes_importantes() \
-               if c.libelle != "PAS_DE_CLASSE"]
+               if c.libelle != NOCLASS]
     listes = {
         c: Eleves.objects.filter(classe = c).order_by('NomPrenomEleve') \
         for c in classes
@@ -442,11 +477,11 @@ def listes_eleves(request):
     if not listes:
         # on renvoie un dictionnaire avec un élève bidon
         bidon = Eleves(
-            Nom_de_famille = "Il n'y a pas encore d'élèves",
-            Prenom = "Il faudrait nourrir la base de données !",
+            Nom_de_famille = _("Il n'y a pas encore d'élèves"),
+            Prenom = _("Il faudrait nourrir la base de données !"),
         )
         listes = {
-            "2d00": [bidon]
+            _("2d00"): [bidon]
         }
     return render_pdf(
         request,
@@ -456,6 +491,6 @@ def listes_eleves(request):
             "min_livres_emoji": 3, # case cochée pour plus de trois livres
             "colWidths": "1.8cm,1cm,5.6cm,3.4cm,6.2cm",
         },
-        filename="listes_eleves.pdf",
+        filename=_("listes_eleves.pdf"),
     )
     
